plot.shrinkMVGPR: Graphical summary of posterior of theta

View source: R/plot_functions.R

plot.shrinkMVGPRR Documentation

Graphical summary of posterior of theta

Description

plot.shrinkMVGPR generates a boxplot visualizing the posterior distribution of theta obtained from a fitted shrinkMVGPR object.

Usage

## S3 method for class 'shrinkMVGPR'
plot(x, nsamp = 1000, ...)

Arguments

x

a shrinkMVGPR object.

nsamp

a positive integer specifying the number of posterior samples to draw for plotting. The default is 1000.

...

further arguments passed to the internal boxplot function, such as axis labeling or plotting options. By default, las = 2 is used unless explicitly overridden by the user.

Value

Called for its side effects. Returns invisible(NULL).

Author(s)

Peter Knaus peter.knaus@wu.ac.at

See Also

Other plotting functions: plot.shrinkGPR(), plot.shrinkGPR_marg_samples_1D(), plot.shrinkGPR_marg_samples_2D(), plot.shrinkTPR()

Examples


if (torch::torch_is_installed()) {
# Simulate and fit a shrinkMVGPR model, then plot:
sim <- simMVGPR()
mod <- shrinkMVGPR(cbind(y.1, y.2) ~ ., data = sim$data)
plot(mod)

## Change axis label orientation
plot(mod, las = 1)
}



shrinkGPR documentation built on March 30, 2026, 5:06 p.m.