View source: R/plot_functions.R
| plot.shrinkMVGPR | R Documentation |
plot.shrinkMVGPR generates a boxplot visualizing the posterior distribution of
theta obtained from a fitted shrinkMVGPR object.
## S3 method for class 'shrinkMVGPR'
plot(x, nsamp = 1000, ...)
x |
a |
nsamp |
a positive integer specifying the number of posterior samples to draw for plotting.
The default is |
... |
further arguments passed to the internal |
Called for its side effects. Returns invisible(NULL).
Peter Knaus peter.knaus@wu.ac.at
Other plotting functions:
plot.shrinkGPR(),
plot.shrinkGPR_marg_samples_1D(),
plot.shrinkGPR_marg_samples_2D(),
plot.shrinkTPR()
if (torch::torch_is_installed()) {
# Simulate and fit a shrinkMVGPR model, then plot:
sim <- simMVGPR()
mod <- shrinkMVGPR(cbind(y.1, y.2) ~ ., data = sim$data)
plot(mod)
## Change axis label orientation
plot(mod, las = 1)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.